@@ -5,7 +5,7 @@ use warnings;
 use Carp qw/croak/;
 use Scalar::Util qw/reftype/;
 
-our $VERSION = '0.000003';
+our $VERSION = '0.000004';
 
 my %DEFAULTS = (
     ALL => {default => undef, list => 0, example => '', required => 0, process => undef},
@@ -190,8 +190,14 @@ sub process_opt {
         : 'bool';
 
     my $process = delete $params{process};
-    croak "process must either be a coderef or a regexp (got: $process)"
-        if $process && !(ref $process && reftype($process) =~ m/^(REGEXP|CODE)$/);
+    if ($process) {
+        my $type = reftype($process);
+        my $ok = $type && ($type eq 'REGEXP' || $type eq 'CODE');
+        $ok ||= $process =~ m/^\(\?/;
+
+        croak "process must either be a coderef or a regexp (got: $process)"
+            unless $process;
+    }
 
     my $alias = delete $params{alias} || [];
     $alias = [$alias] unless ref $alias;
